//
//  BlueToothManager.h
//  HandheldBluetooth
//
//  Created by 伟 on 2018/10/23.
//  Copyright © 2018年 ZW. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "BabyBluetooth.h"

NS_ASSUME_NONNULL_BEGIN

@protocol BlueToothManagerDelegate <NSObject>


/**
 搜索获取到的周边设备信息

 @param peripheralArr <#peripheralArr description#>
 */
-(void)getAllPeripheralWithArr:(NSArray *)peripheralArr;

//连接状态提示信息
-(void)connectStateUpdateWithShowStr:(NSString *)showStr AndIsShow:(BOOL)isShow;

//获取外设电量
-(void)getPeripheralElectricityWithStr:(NSString *)electricityStr;


/**
 连接状态变化

 @param state 状态
 */
-(void)connectPeripheralWithState:(NSInteger)state;  //1.成功

@end

@protocol BlueToothManagerDataDelegate <NSObject>

//获取外设电量
-(void)getPeripheralElectricityWithStr:(NSString *)electricityStr;

//RFID功率大小
-(void)getPeripheralRFIDPowerWithStr:(NSString *)RFIDStr;

//获取读取速度
-(void)getPeripheralReadSpeedWithStr:(NSString *)speedStr;

//获取临界值
-(void)getPeripheralCriticalWithStr:(NSString *)criticalStr;

//获取减小的单位值
-(void)getPeripheralReduceUnitWithStr:(NSString *)reduceUnitStr;

//获取音量
-(void)getPeripheralVolumeWithStr:(NSString *)volumeStr;

//获取只读新的标签
-(void)getPeripheralNewLableWithStr:(NSString *)newLabelStr;

//获取持续读取
-(void)getPeripheralContinueReadWithStr:(NSString *)continueReadStr;

//获取允许菜单
-(void)getPeripheralAllowMeauWithStr:(NSString *)allowMeauStr;

//获取语言
-(void)getPeripheralLanguageWithStr:(NSString *)languageStr;

@end


@protocol BlueToothManagerTagListDelegate <NSObject>

//获取标签列表数据
-(void)getTagListWithStr:(NSString *)tagListHexStr;

//获取标签列表数据(清空后)
-(void)getClearTagListWithStr:(NSString *)tagListASCIIStr;

//通配符搜索数据
-(void)getWailcardTagListWithStr:(NSString *)tagListWailcardASCIIStr;

//清空搜索列表通知
-(void)clearSearchListNot;

//重启RFID搜索
-(void)restartRFIDSearch;

//扫码
-(void)getSweepYardWithStr:(NSString *)HEXStr;

//扫码状态
-(void)ScavengingState:(BOOL)isSweep;

//读取类型
-(void)getReadType:(NSString *)typeStr;

//获取全部标签数量值
-(void)getTagListTotal:(NSString *)totalStr;

//暂停
-(void)getStopOrder;

@end

@protocol BlueToothManagerWriteDelegate <NSObject>

//获取写功率
-(void)getWritePowerWithStr:(NSString *)writePowerHexStr;

//获取写标签回复
-(void)getWriteLabelWithReplyStr:(NSString *)replyHexStr;

@end

@protocol BlueToothManagerMemoryAccessDelegate <NSObject>

//获取内存访问回复
-(void)getMemoryAccessWithReplyStr:(NSString *)replyHexStr;

//获取内存访问回复
-(void)getMemoryReadWithReadStr:(NSString *)readHexStr;

@end

@interface BlueToothManager : NSObject

@property (nonatomic, strong) NSMutableArray *peripheralDataArray;// 搜索到所有的设备

@property (nonatomic, assign) BOOL bluetoothStateOn;   //蓝牙打开

@property (nonatomic, strong) CBPeripheral * currentPeripheral;// 正在连接的蓝牙设备

@property (nonatomic, weak) id<BlueToothManagerDelegate>delegate;

@property (nonatomic, weak) id<BlueToothManagerDataDelegate>dataDelegate;

@property (nonatomic, weak) id<BlueToothManagerTagListDelegate>tagListDelegate;

@property (nonatomic, weak) id<BlueToothManagerWriteDelegate>writeDelegate;

@property (nonatomic, weak) id<BlueToothManagerMemoryAccessDelegate>memoryDelegate;

@property (nonatomic, assign) BOOL isGetAllInfoReply;   //获取外设所有命令回调信息

/**
 单例管理

 @return 当前实例
 */
+ (instancetype)sharedManager;

/**
 搜索外设
 */
- (void)scanForPeripherals;

//停止扫描
-(void)stopScan;

/**
 连接外设

 @param peripheral 外设
 */
- (void)connectPeripheral:(CBPeripheral *)peripheral;

/**
 断开外设连接

 @param peripheral 外设
 */
- (void)disconnectPeripheral:(CBPeripheral *)peripheral;


/**
 发命令

 @param string 命令
 */
- (void)wirteData:(NSString *)string;

//读特征信息
-(void)readInfoData;

//标签列表搜索命令
- (void)wirteTagListSearchData:(NSString *)string;

//标签列表搜索命令(开始)
- (void)wirteTagListContinueSearchData:(NSString *)string;

//写标签命令
- (void)wirteLabelData:(NSString *)string;

//内存访问命令
- (void)wirteMemoryAccessData:(NSString *)string;

//内存访问读取命令
-(void)wirteMemoryAccessReadData:(NSString *)string;

@end

NS_ASSUME_NONNULL_END
